package it.unibas.acibase.test;

import it.unibas.acibase.modello.Automobile;
import it.unibas.acibase.modello.Proprietario;
import it.unibas.acibase.persistenza.DAOAutomobile;
import it.unibas.acibase.persistenza.DAOProprietario;
import it.unibas.utilita.Logger;
import junit.framework.TestCase;

public class TestDAOAutomobile extends TestCase {
    
    static {
        Logger.setLevel(java.util.logging.Level.INFO);
    }
    
    private Automobile automobile;
    private Proprietario proprietario;
    
    protected void setUp() {
        proprietario = new Proprietario();
        proprietario.setCodiceFiscale("cftest1");
        proprietario.setNome("Proprietario di test");
        proprietario.setCittaDiResidenza("citta di test");
        proprietario.setAnnoPatente(2003);
        automobile = new Automobile();
        automobile.setTarga("test1");
        automobile.setModello("Modello di test");
        automobile.setCilindrata(2000);
    }
    
    public void testInserisciAutomobile() {
        try {
            DAOProprietario.doInsert(proprietario);
            automobile.setProprietario(proprietario);            
            DAOAutomobile.doInsert(automobile);
            Automobile automobile1 = DAOAutomobile.doSelectTarga("test1");
            assertNotNull(automobile1);
            assertEquals(automobile1.getTarga(), "test1");
            assertEquals(automobile1.getModello(), "Modello di test");
            assertEquals(automobile1.getCilindrata(), 2000);
        } catch (Exception e) {
            System.err.println(e);
            fail();
        } finally {
            try {
                DAOAutomobile.doDelete(automobile);
                DAOProprietario.doDelete(proprietario);
            } catch (Exception e) {
                System.out.println(e);
            }
        }
    }
    
    
    public void testCercaAutomobile() {
        try {
            DAOProprietario.doInsert(proprietario);
            automobile.setProprietario(proprietario);
            Automobile automobile2 = DAOAutomobile.doSelectTarga("test1");
            assertTrue("non trovata", automobile2 == null);
            automobile.setProprietario(proprietario);
            DAOAutomobile.doInsert(automobile);
            automobile2 = DAOAutomobile.doSelectTarga("test1");
            DAOAutomobile.caricaProprietario(automobile2);
            assertNotNull(automobile2);
            assertEquals(automobile2.getTarga(), "test1");
            assertEquals(automobile2.getModello(), "Modello di test");
            assertEquals(automobile2.getCilindrata(), 2000);
            assertEquals(automobile2.getProprietario().getCodiceFiscale(), "cftest1");
        } catch (Exception e) {
            System.err.println(e);
            fail();
        } finally {
            try {
                DAOAutomobile.doDelete(automobile);
                DAOProprietario.doDelete(proprietario);
            } catch (Exception e) {
                System.out.println(e);
            }
        }
    }
    
    public void testAggiornaAutomobile() {
        try {
            DAOProprietario.doInsert(proprietario);
            automobile.setProprietario(proprietario);
            DAOAutomobile.doInsert(automobile);            
            automobile = DAOAutomobile.doSelectTarga("test1");
            DAOAutomobile.caricaProprietario(automobile);
            assertTrue("trovato", automobile != null);
            automobile.setModello("Nuovo modello di test");
            DAOAutomobile.doUpdate(automobile);
            Automobile automobile1 = DAOAutomobile.doSelectTarga("test1");
            assertNotNull(automobile1);
            assertEquals(automobile1.getTarga(), "test1");
            assertEquals(automobile1.getModello(), "Nuovo modello di test");
            assertEquals(automobile1.getCilindrata(), 2000);
        } catch (Exception e) {
            System.err.println(e);
            fail();
        } finally {
            try {
                DAOAutomobile.doDelete(automobile);
                DAOProprietario.doDelete(proprietario);
            } catch (Exception e) {
                System.out.println(e);
            }
        }
    }
    
}
