package it.unibas.acibase.test;

import it.unibas.acibase.modello.Automobile;
import it.unibas.acibase.modello.Proprietario;
import it.unibas.acibase.persistenza.DAOAutomobile;
import it.unibas.acibase.persistenza.DAOProprietario;
import it.unibas.acibase.persistenza.DataSource;
import it.unibas.utilita.Logger;
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.Statement;
import java.util.List;
import junit.framework.TestCase;

public class TestDAOProprietario extends TestCase {
        
    static {
        Logger.setLevel(java.util.logging.Level.INFO);
    }

    private Proprietario proprietario;
    private Proprietario proprietario2;
    private Automobile automobile;
    private Automobile automobile2;
    
    protected void setUp() {
        proprietario = new Proprietario();
        proprietario.setCodiceFiscale("cftest2");
        proprietario.setNome("Proprietario di test");
        proprietario.setCittaDiResidenza("citta di test");
        proprietario.setAnnoPatente(2003);
        proprietario2 = new Proprietario();
        proprietario2.setCodiceFiscale("cftest3");
        proprietario2.setNome("Proprietario di test");
        proprietario2.setCittaDiResidenza("citta di test");
        proprietario2.setAnnoPatente(2003);
        automobile = new Automobile();
        automobile.setTarga("test3");
        automobile.setModello("Modello di test");
        automobile.setCilindrata(2000);
        automobile.setProprietario(proprietario);
        automobile2 = new Automobile();
        automobile2.setTarga("test4");
        automobile2.setModello("Modello di test");
        automobile2.setCilindrata(2000);
        automobile2.setProprietario(proprietario);
    }
    
    public void testInserisciProprietario() {
        try {
            DAOProprietario.doInsert(proprietario);
            Proprietario proprietario1 = DAOProprietario.doSelectCodiceFiscale("cftest2");
            assertNotNull(proprietario1);
            assertEquals(proprietario1.getNome(), "Proprietario di test");
            assertEquals(proprietario1.getCittaDiResidenza(), "citta di test");
            assertEquals(proprietario1.getAnnoPatente(), 2003);
        } catch (Exception e) {
            System.err.println(e);
            fail();
        } finally {
            try {
                DAOProprietario.doDelete(proprietario);
            } catch (Exception e) {
                System.out.println(e);
            }
        }
    }

    public void testCaricaAutomobiliProprietario() {
        try {
            DAOProprietario.doInsert(proprietario);
            DAOAutomobile.doInsert(automobile);
            DAOProprietario.caricaAutomobili(proprietario);
            assertTrue("una automobile", proprietario.getNumeroAutomobili() == 1);
            DAOAutomobile.doInsert(automobile2);
            DAOProprietario.caricaAutomobili(proprietario);
            assertTrue("due automobili", proprietario.getNumeroAutomobili() == 2);
        } catch (Exception e) {
            System.err.println(e);
            fail();
        } finally {
            try {
                DAOAutomobile.doDelete(automobile);
                DAOAutomobile.doDelete(automobile2);
                DAOProprietario.doDelete(proprietario);
            } catch (Exception e) {
                System.out.println(e);
            }
        }
    }
    
    public void testCercaPerCodiceFiscale() {
        try {
            Proprietario proprietariox = DAOProprietario.doSelectCodiceFiscale("cftest2");
            assertTrue("non trovato", proprietariox == null);
            DAOProprietario.doInsert(proprietario);
            proprietariox = DAOProprietario.doSelectCodiceFiscale("cftest2");
            assertTrue("trovato", proprietariox != null);
            assertTrue("codice fiscale", proprietariox.getCodiceFiscale().equals("cftest2"));
            assertTrue("nome", proprietariox.getNome().equals("Proprietario di test"));
            assertTrue("citta di residenza", proprietariox.getCittaDiResidenza().equals("citta di test"));
            assertTrue("anno patente", proprietariox.getAnnoPatente() == 2003);
            assertTrue("numero automobili", proprietariox.getNumeroAutomobili() == 0);
        } catch (Exception e) {
            System.err.println(e);
            fail();
        } finally {
            try {
               DAOProprietario.doDelete(proprietario);
            } catch (Exception e) {
                System.out.println(e);
            }
        }
    }

    public void testAggiornaProprietario() {
        try {
            DAOProprietario.doInsert(proprietario);
            proprietario = DAOProprietario.doSelectCodiceFiscale("cftest2");
            assertTrue("trovato", proprietario != null);
            proprietario.setNome("Nuovo proprietario di test");
            DAOProprietario.doUpdate(proprietario);
            Proprietario proprietario1 = DAOProprietario.doSelectCodiceFiscale("cftest2");
            assertNotNull(proprietario1);
            assertEquals(proprietario1.getNome(), "Nuovo proprietario di test");
            assertEquals(proprietario1.getCittaDiResidenza(), "citta di test");
            assertEquals(proprietario1.getAnnoPatente(), 2003);
        } catch (Exception e) {
            System.err.println(e);
            fail();
        } finally {
            try {
                DAOProprietario.doDelete(proprietario);
            } catch (Exception e) {
                System.out.println(e);
            }
        }
    }
    
    public void testCercaPerNome() {
        try {
            List listaProprietari = DAOProprietario.doSelectNome("Proprietario di test");
            assertTrue("lista vuota", listaProprietari.size() == 0);
            DAOProprietario.doInsert(proprietario);
            listaProprietari = DAOProprietario.doSelectNome("Proprietario di test");
            assertTrue("un proprietario", listaProprietari.size() == 1);
            DAOProprietario.doInsert(proprietario2);
            listaProprietari = DAOProprietario.doSelectNome("Proprietario di test");
            assertTrue("due proprietari", listaProprietari.size() == 2);
        } catch (Exception e) {
            System.err.println(e);
            fail();
        } finally {
            try {
                DAOProprietario.doDelete(proprietario);
                DAOProprietario.doDelete(proprietario2);
            } catch (Exception e) {
                System.out.println(e);
            }
        }
    }

}
